psychopy_ext.exp.default_computer
=================================

.. currentmodule:: psychopy_ext.exp

.. autoclass:: default_computer

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~default_computer.__init__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~default_computer.default_keys
      ~default_computer.distance
      ~default_computer.name
      ~default_computer.recognized
      ~default_computer.root
      ~default_computer.screen
      ~default_computer.stereo
      ~default_computer.valid_responses
      ~default_computer.view_scale
      ~default_computer.width
   
   